Struct Ctrl1
Source #[repr(transparent)]
pub struct Ctrl1(pub u16);
Crossbar A Control Register 1.
DMA Enable for XBAR_OUT2.
DMA Enable for XBAR_OUT2.
Interrupt Enable for XBAR_OUT2.
Interrupt Enable for XBAR_OUT2.
Active edge for edge detection on XBAR_OUT2.
Active edge for edge detection on XBAR_OUT2.
Edge detection status for XBAR_OUT2.
Edge detection status for XBAR_OUT2.
DMA Enable for XBAR_OUT3.
DMA Enable for XBAR_OUT3.
Interrupt Enable for XBAR_OUT3.
Interrupt Enable for XBAR_OUT3.
Active edge for edge detection on XBAR_OUT3.
Active edge for edge detection on XBAR_OUT3.
Edge detection status for XBAR_OUT3.
Edge detection status for XBAR_OUT3.
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.